﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MSHO.Collection.Service.IO
{
    partial class IOServer
    {
        private Dictionary<string, MSHO.Collection.DataAccess.Models.CollectConfig> m_CollectConfigs = new Dictionary<string, DataAccess.Models.CollectConfig>();

        private void Process_Exception(System.Net.Sockets.Socket client, Msg data) {
            var msg = new ErrorMsgRespMsg();
            msg.ClientCode = data.ClientCode;

            var error_msg = data as ErrorMsg;
            if (error_msg != null)
            {
                var clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                if (clientConfig != null) {
                    if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog(MSHO.Collection.DataAccess.Enums.SystemLogTypeEnum.ERROR, "MSHO.Collection.Client", error_msg.Model, error_msg.LogMessage, error_msg.LogDetails, clientConfig.CollectorName, clientConfig.Code))
                    {
                        msg.Result = true;
                    }
                }
            }

            SendMsg(client, new Message(msg));
        }

        private void Process_Bus_Weighting(DataReportRespMsg msg, DataReportMsg data_report) {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.Bus_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion
                
                if (clientConfig != null)
                {
                    #region check exist
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.ReceiveTime;
                    bool exist = false;

                    if (weighting.Id.HasValue)
                    {
                        clientConfig.LastSourceID = weighting.Id.ToString();
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, clientConfig.LastSourceID);
                    }
                    #endregion

                    string weightId = weighting.Id.HasValue ? weighting.Id.ToString() : string.Empty;
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    }
                    else
                    {
                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = weightId,
                            WeightTime = weighting.WeightTime,
                            TruckNumber = weighting.TruckNumber,
                            TruckColor = weighting.TruckCorlor,
                            CaptureTime = weighting.TruckCapTime,
                            ThroughDuring = weighting.Difference,
                            LimitMode = weighting.LimitModeName,
                            VehicleType = weighting.VehicleType,
                            AxleType = weighting.AxleType,
                            AxleCount = weighting.AxleCount,
                            LaneNumber = weighting.LaneNum,
                            Way = weighting.Way,
                            IsReverse = weighting.IsReverse,
                            IsBoast = weighting.IsBoast,
                            Speed = weighting.Speed,
                            PressColumn = weighting.PressColumns,
                            Gross = weighting.Gross,
                            LimitWeight = weighting.LimitWeight,
                            OverloadWeight = weighting.OverWeight,
                            OverloadRate = weighting.LimiteRate,
                            AxleWeight1 = weighting.AxleWeight1,
                            AxleWeight2 = weighting.AxleWeight2,
                            AxleWeight3 = weighting.AxleWeight3,
                            AxleWeight4 = weighting.AxleWeight4,
                            AxleWeight5 = weighting.AxleWeight5,
                            AxleWeight6 = weighting.AxleWeight6,
                            AxleWeight7 = weighting.AxleWeight7,
                            AxleWeight8 = weighting.AxleWeight8,
                            UploadTime = DateTime.Now
                        };

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }

                        #region 附件
                        foreach (var file in weighting.WeightingFiles)
                        {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_Bus_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }
                }
            }
        }

        private void Process_Kdtc_Weighting(DataReportRespMsg msg, DataReportMsg data_report)
        {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.Kdtc_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion

                if (clientConfig != null)
                {
                    #region check exist
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.CollectTime;
                    bool exist = false;

                    if (weighting.Id.HasValue)
                    {
                        clientConfig.LastSourceID = weighting.Id.ToString();
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, clientConfig.LastSourceID);
                    }
                    #endregion

                    string weightId = weighting.Id.HasValue ? weighting.Id.ToString() : string.Empty;
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    } else {
                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = weightId,
                            WeightTime = weighting.WeightTime,
                            TruckNumber = weighting.TruckNumber,
                            TruckColor = weighting.TruckCorlor,
                            CaptureTime = weighting.TruckCapTime,
                            ThroughDuring = weighting.Difference,
                            LimitMode = weighting.LimitModeName,
                            VehicleType = weighting.VehicleType,
                            AxleType = weighting.AxleType,
                            AxleCount = weighting.AxleCount,
                            LaneNumber = weighting.EnterLane,
                            LeaveLane = weighting.LeaveLane,
                            Way = weighting.Way,
                            IsReverse = weighting.IsReverse,
                            IsBoast = weighting.IsBoast,
                            Speed = weighting.Speed,
                            LimitSpeed = weighting.LimitSpeed,
                            OverSpeed = weighting.OverSpeed,
                            PressColumn = weighting.PressColumns,
                            Gross = weighting.Gross,
                            LimitWeight = weighting.LimitWeight,
                            OverloadWeight = weighting.OverWeight,
                            OverloadRate = weighting.LimiteRate,
                            AxleWeight1 = weighting.AxleWeight1,
                            AxleWeight2 = weighting.AxleWeight2,
                            AxleWeight3 = weighting.AxleWeight3,
                            AxleWeight4 = weighting.AxleWeight4,
                            AxleWeight5 = weighting.AxleWeight5,
                            AxleWeight6 = weighting.AxleWeight6,
                            AxleWeight7 = weighting.AxleWeight7,
                            AxleWeight8 = weighting.AxleWeight8,

                            Length = weighting.Length,
                            Width = weighting.Width,
                            Height = weighting.Height,
                            UploadTime = DateTime.Now
                        };

                        if (serverWeighting.OverloadRate.HasValue)
                        {//计算限载率
                            if (serverWeighting.OverloadRate.Value > 0)
                            {
                                serverWeighting.OverloadRate = serverWeighting.OverloadRate.Value / (decimal)100.00;
                            }
                        }

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }

                        #region 附件
                        foreach (var file in weighting.WeightingFiles)
                        {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_Kdtc_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }

                }
            }
        }

        private void Process_Access_Weighting(DataReportRespMsg msg, DataReportMsg data_report)
        {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.Access_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion

                if (clientConfig != null)
                {
                    #region check exist
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.WeightTime;
                    bool exist = false;

                    if (weighting.ID.HasValue)
                    {
                        clientConfig.LastSourceID = weighting.ID.ToString();
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, clientConfig.LastSourceID);
                    }
                    #endregion

                    string weightId = weighting.ID.HasValue ? weighting.ID.ToString() : string.Empty;
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    }
                    else
                    {
                        string axleType = null;
                        if (!string.IsNullOrEmpty(weighting.LicenseNo)) {
                            var n = weighting.LicenseNo.LastIndexOf("-");
                            if (n > 0)
                            {
                                axleType = weighting.LicenseNo.Substring(n + 1);
                            }
                        }

                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = weightId,
                            WeightTime = weighting.WeightTime,
                            TruckNumber = weighting.TruckNumber,
                            CaptureTime = weighting.WeightTime,
                            AxleCount = weighting.AxleCount,
                            AxleType = axleType,
                            Speed = weighting.Speed,
                            Gross = weighting.Gross,
                            LimitWeight = weighting.LimitWeight,
                            OverloadRate = weighting.OverloadRate,

                            Checker = weighting.Checker,
                            LicenseNo = weighting.LicenseNo,
                            Sequence = weighting.Sequence,
                            GPRS = weighting.GPRS,
                            Width = weighting.w,
                            Height = weighting.h,

                            UploadTime = DateTime.Now
                        };

                        if (serverWeighting.Gross.HasValue && weighting.LimitWeight.HasValue)
                        {
                            serverWeighting.OverloadWeight = weighting.Gross.Value - weighting.LimitWeight.Value;
                            if (serverWeighting.OverloadWeight < 0)
                            {
                                serverWeighting.OverloadWeight = 0;
                            }
                        }

                        if (serverWeighting.OverloadRate.HasValue)
                        {
                            if (serverWeighting.OverloadRate.Value > 0)
                            {
                                serverWeighting.OverloadRate = serverWeighting.OverloadRate.Value / (decimal)100.00;
                            }
                        }

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }

                        #region 附件
                        foreach (var file in weighting.WeightingFiles) {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_Access_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }
                }
            }
        }

        private void Process_SQL2000_DiBangData_Weighting(DataReportRespMsg msg, DataReportMsg data_report)
        {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.SQL2000_DiBangData_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion

                if (clientConfig != null)
                {
                    #region check exist
                    string prexWeightId = string.Empty;
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.WeightTime;
                    bool exist = false;

                    if (weighting.ID.HasValue)
                    {
                        prexWeightId = string.Format("SQL2000_{0}", weighting.ID.Value);
                        clientConfig.LastSourceID = weighting.ID.ToString();
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, prexWeightId);
                    }
                    #endregion

                    string weightId = weighting.ID.HasValue ? weighting.ID.Value.ToString() : string.Empty;
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    }
                    else
                    {
                        string axleType = null;
                        if (!string.IsNullOrEmpty(weighting.LicenseNo))
                        {
                            var n = weighting.LicenseNo.LastIndexOf("-");
                            if (n > 0)
                            {
                                axleType = weighting.LicenseNo.Substring(n + 1);
                            }
                        }
                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = prexWeightId,
                            WeightTime = weighting.WeightTime,
                            TruckNumber = weighting.TruckNumber,
                            CaptureTime = weighting.WeightTime,
                            AxleType = axleType,
                            AxleCount = weighting.AxleCount,
                            Speed = weighting.Speed,
                            Gross = weighting.Gross,
                            LimitWeight = weighting.LimitWeight,
                            OverloadRate = weighting.OverloadRate,

                            Checker = weighting.Checker,
                            LicenseNo = weighting.LicenseNo,
                            Sequence = weighting.Sequence,
                            GPRS = weighting.GPRS,

                            UploadTime = DateTime.Now
                        };

                        if (serverWeighting.Gross.HasValue && weighting.LimitWeight.HasValue)
                        {
                            serverWeighting.OverloadWeight = weighting.Gross.Value - weighting.LimitWeight.Value;
                            if (serverWeighting.OverloadWeight < 0)
                            {
                                serverWeighting.OverloadWeight = 0;
                            }
                        }

                        if (serverWeighting.OverloadRate.HasValue)
                        {
                            if (serverWeighting.OverloadRate.Value > 0)
                            {
                                serverWeighting.OverloadRate = serverWeighting.OverloadRate.Value / (decimal)100.00;
                            }
                        }

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }

                        #region 附件
                        foreach (var file in weighting.WeightingFiles)
                        {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_SQL2000_DiBangData_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }
                }
            }
        }

        private void Process_SQL2000_oreManageDBCli_Weighting(DataReportRespMsg msg, DataReportMsg data_report)
        {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.SQL2000_oreManageDBCli_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion

                if (clientConfig != null)
                {
                    #region check exist
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.WeightTime;
                    bool exist = false;

                    if (weighting.ID.HasValue)
                    {
                        clientConfig.LastSourceID = weighting.ID.ToString();
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, clientConfig.LastSourceID);
                    }
                    #endregion
                   
                    string weightId = weighting.ID.HasValue ? weighting.ID.Value.ToString() : string.Empty;
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    }
                    else
                    {
                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = weightId,
                            WeightTime = weighting.checkdate,
                            TruckNumber = weighting.licenseplate,
                            CaptureTime = weighting.checkdate,
                            AxleCount = weighting.axleCount,
                            Gross = weighting.totalWeigh,
                            LimitWeight = weighting.amountWeigh,
                            OverloadWeight = 0,
                            OverloadRate = weighting.overRatio,

                            Checker = weighting.@operator,
                            Remark = weighting.descript,

                            UploadTime = DateTime.Now
                        };


                        if (serverWeighting.Gross.HasValue)
                        {
                            if (serverWeighting.Gross.Value > 0)
                            {
                                serverWeighting.Gross /= 1000;
                            }
                        }
                        if (serverWeighting.LimitWeight.HasValue)
                        {
                            if (serverWeighting.LimitWeight.Value > 0)
                            {
                                serverWeighting.LimitWeight /= 1000;
                            }
                        }

                        if (serverWeighting.Gross.HasValue && serverWeighting.LimitWeight.HasValue)
                        {
                            if (serverWeighting.Gross.Value > serverWeighting.LimitWeight.Value)
                            {
                                serverWeighting.OverloadWeight = serverWeighting.Gross.Value - serverWeighting.LimitWeight.Value;
                            }
                        }

                        if (serverWeighting.OverloadRate.HasValue)
                        {
                            if (serverWeighting.OverloadRate.Value > 0)
                            {
                                serverWeighting.OverloadRate = serverWeighting.OverloadRate.Value / (decimal)100.00;
                            }
                        }

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }

                        #region 附件
                        foreach (var file in weighting.WeightingFiles)
                        {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_SQL2000_oreManageDBCli_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }
                }
            }
        }

        private void Process_SQL2000_oreManageDBCli_2_Weighting(DataReportRespMsg msg, DataReportMsg data_report)
        {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.SQL2000_oreManageDBCli_2_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion

                if (clientConfig != null)
                {
                    #region check exist
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.WeightTime;
                    bool exist = false;

                    if (weighting.ID.HasValue)
                    {
                        clientConfig.LastSourceID = weighting.ID.ToString();
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, clientConfig.LastSourceID);
                    }
                    #endregion

                    string weightId = weighting.ID.HasValue ? weighting.ID.Value.ToString() : string.Empty;
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    }
                    else
                    {
                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = weightId,
                            WeightTime = weighting.checkdate,
                            TruckNumber = weighting.licenseplate,
                            CaptureTime = weighting.checkdate,

                            AxleCount = weighting.axleCount,
                            AxleType = weighting.vehicleType,
                            Way = weighting.direction,
                            LaneNumber = weighting.roadNum,

                            Gross = weighting.totalWeigh,
                            LimitWeight = weighting.amountWeigh,
                            OverloadWeight = weighting.overWeigh,
                            OverloadRate = weighting.overRatio,

                            Checker = weighting.@operator,

                            UploadTime = DateTime.Now
                        };

                        #region axleWeight
                        if (!string.IsNullOrEmpty(weighting.axleWeight)) {
                            int num = 0;
                            var sp = weighting.axleWeight.Split(new char[] { ';' }, StringSplitOptions.RemoveEmptyEntries);
                            switch (sp.Length) {
                                case 1:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    break;
                                case 2:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    break;
                                case 3:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    break;
                                case 4:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    break;
                                case 5:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    break;
                                case 6:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    if (int.TryParse(sp[5], out num)) { serverWeighting.AxleWeight6 = num; }
                                    break;
                                case 7:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    if (int.TryParse(sp[5], out num)) { serverWeighting.AxleWeight6 = num; }
                                    if (int.TryParse(sp[6], out num)) { serverWeighting.AxleWeight7 = num; }
                                    break;
                                case 8:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    if (int.TryParse(sp[5], out num)) { serverWeighting.AxleWeight6 = num; }
                                    if (int.TryParse(sp[6], out num)) { serverWeighting.AxleWeight7 = num; }
                                    if (int.TryParse(sp[7], out num)) { serverWeighting.AxleWeight8 = num; }
                                    break;
                            }
                        }
                        #endregion

                        if (serverWeighting.Gross.HasValue)
                        {
                            if (serverWeighting.Gross.Value > 0)
                            {
                                serverWeighting.Gross /= 1000;
                            }
                        }
                        if (serverWeighting.LimitWeight.HasValue)
                        {
                            if (serverWeighting.LimitWeight.Value > 0)
                            {
                                serverWeighting.LimitWeight /= 1000;
                            }
                        }

                        if (serverWeighting.OverloadWeight.HasValue)
                        {
                            if (serverWeighting.OverloadWeight.Value > 0)
                            {
                                serverWeighting.OverloadWeight /= 1000;
                            }
                        }

                        if (serverWeighting.OverloadRate.HasValue)
                        {
                            if (serverWeighting.OverloadRate.Value > 0)
                            {
                                serverWeighting.OverloadRate = serverWeighting.OverloadRate.Value / (decimal)100.00;
                            }
                        }

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }

                        #region 附件
                        foreach (var file in weighting.WeightingFiles)
                        {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_SQL2000_oreManageDBCli_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }
                }
            }
        }

        private void Process_SQL2000_oreManageDBCli_3_Weighting(DataReportRespMsg msg, DataReportMsg data_report)
        {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.SQL2000_oreManageDBCli_3_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion

                if (clientConfig != null)
                {
                    #region check exist
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.WeightTime;
                    bool exist = false;

                    if (weighting.ID.HasValue)
                    {
                        clientConfig.LastSourceID = weighting.ID.ToString();
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, clientConfig.LastSourceID);
                    }
                    #endregion

                    string weightId = weighting.ID.HasValue ? weighting.ID.Value.ToString() : string.Empty;
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    }
                    else
                    {
                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = weightId,
                            WeightTime = weighting.checkdate,
                            TruckNumber = weighting.licenseplate,
                            CaptureTime = weighting.checkdate,

                            AxleCount = weighting.axleCount,
                            AxleType = weighting.vehicleType,
                            LaneNumber = weighting.roadNum,

                            Gross = weighting.totalWeigh,
                            LimitWeight = weighting.amountWeigh,
                            OverloadWeight = weighting.overWeigh,
                            OverloadRate = weighting.overRatio,

                            Checker = weighting.@operator,

                            UploadTime = DateTime.Now
                        };

                        #region axleWeight
                        if (!string.IsNullOrEmpty(weighting.axleWeight))
                        {
                            int num = 0;
                            var sp = weighting.axleWeight.Split(new char[] { ';' }, StringSplitOptions.RemoveEmptyEntries);
                            switch (sp.Length)
                            {
                                case 1:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    break;
                                case 2:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    break;
                                case 3:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    break;
                                case 4:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    break;
                                case 5:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    break;
                                case 6:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    if (int.TryParse(sp[5], out num)) { serverWeighting.AxleWeight6 = num; }
                                    break;
                                case 7:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    if (int.TryParse(sp[5], out num)) { serverWeighting.AxleWeight6 = num; }
                                    if (int.TryParse(sp[6], out num)) { serverWeighting.AxleWeight7 = num; }
                                    break;
                                case 8:
                                    if (int.TryParse(sp[0], out num)) { serverWeighting.AxleWeight1 = num; }
                                    if (int.TryParse(sp[1], out num)) { serverWeighting.AxleWeight2 = num; }
                                    if (int.TryParse(sp[2], out num)) { serverWeighting.AxleWeight3 = num; }
                                    if (int.TryParse(sp[3], out num)) { serverWeighting.AxleWeight4 = num; }
                                    if (int.TryParse(sp[4], out num)) { serverWeighting.AxleWeight5 = num; }
                                    if (int.TryParse(sp[5], out num)) { serverWeighting.AxleWeight6 = num; }
                                    if (int.TryParse(sp[6], out num)) { serverWeighting.AxleWeight7 = num; }
                                    if (int.TryParse(sp[7], out num)) { serverWeighting.AxleWeight8 = num; }
                                    break;
                            }
                        }
                        #endregion

                        if (serverWeighting.Gross.HasValue)
                        {
                            if (serverWeighting.Gross.Value > 0)
                            {
                                serverWeighting.Gross /= 1000;
                            }
                        }
                        if (serverWeighting.LimitWeight.HasValue)
                        {
                            if (serverWeighting.LimitWeight.Value > 0)
                            {
                                serverWeighting.LimitWeight /= 1000;
                            }
                        }

                        if (serverWeighting.OverloadWeight.HasValue)
                        {
                            if (serverWeighting.OverloadWeight.Value > 0)
                            {
                                serverWeighting.OverloadWeight /= 1000;
                            }
                        }

                        if (serverWeighting.OverloadRate.HasValue)
                        {
                            if (serverWeighting.OverloadRate.Value > 0)
                            {
                                serverWeighting.OverloadRate = serverWeighting.OverloadRate.Value / (decimal)100.00;
                            }
                        }

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }

                        #region 附件
                        foreach (var file in weighting.WeightingFiles)
                        {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_SQL2000_oreManageDBCli_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }
                }
            }
        }

        private void Process_LowSpeedNew_Weighting(DataReportRespMsg msg, DataReportMsg data_report)
        {
            var weighting = JsonSerializable.FromJson<MSHO.Collection.DataAccess.ClientModels.LowSpeedNew_Weighting>(data_report.Result);
            if (weighting != null)
            {
                #region clientConfig
                MSHO.Collection.DataAccess.Models.CollectConfig clientConfig = null;
                if (m_CollectConfigs.ContainsKey(msg.ClientCode))
                {
                    clientConfig = m_CollectConfigs[msg.ClientCode];
                }
                if (clientConfig == null)
                {
                    clientConfig = MSHO.Collection.DataAccess.MSHOService.Instance.GetCollectConfigByCode(msg.ClientCode);
                }
                #endregion

                if (clientConfig != null)
                {
                    #region check exist
                    if (!m_CollectConfigs.ContainsKey(msg.ClientCode))
                    {
                        m_CollectConfigs.Add(msg.ClientCode, clientConfig);
                    }
                    clientConfig.LastSourceTime = weighting.WeightTime;
                    bool exist = false;

                    if (!string.IsNullOrEmpty(weighting.CheckCode))
                    {
                        clientConfig.LastSourceID = weighting.CheckCode;
                        exist = MSHO.Collection.DataAccess.MSHOService.Instance.ExistWeighting(clientConfig.StationID, clientConfig.DeviceID, clientConfig.LastSourceID);
                    }
                    #endregion

                    string weightId = (string.IsNullOrEmpty(weighting.CheckCode) ? (weighting.LSData_ID.HasValue ? weighting.LSData_ID.Value.ToString() : string.Empty) : weighting.CheckCode);
                    if (exist)
                    {
                        msg.Result = true;
                        msg.DataId = weightId;
                    }
                    else
                    {
                        var serverWeighting = new MSHO.Collection.DataAccess.Models.Weighting()
                        {
                            StationID = clientConfig.StationID,
                            DeviceID = clientConfig.DeviceID,
                            WeightID = weightId,
                            WeightTime = weighting.Check_DT,
                            TruckNumber = weighting.License_Plate,
                            TruckColor = weighting.Plate_Color,
                            CaptureTime = weighting.Check_DT,
                            LaneNumber = (int)weighting.Lane_ID,
                            Speed = weighting.Veh_Speed,

                            AxleCount = (int)weighting.Axle_Num,
                            AxleType = (weighting.Axle_Type.HasValue ? weighting.Axle_Type.Value.ToString() : null),
                            Gross = weighting.Whole_Weight,
                            LimitWeight = weighting.Whole_Limit,
                            OverloadWeight = weighting.Whole_Over,
                            OverloadRate = weighting.Whole_Overrate,

                            Checker = weighting.Staff_ID,
                            Remark = (weighting.Over_Num > 0 ? string.Format("超限次数{0}", weighting.Over_Num) : null),

                            AxleWeight1 = weighting.Axle1_Weight,
                            AxleWeight2 = weighting.Axle2_Weight,
                            AxleWeight3 = weighting.Axle3_Weight,
                            AxleWeight4 = weighting.Axle4_Weight,
                            AxleWeight5 = weighting.Axle5_Weight,
                            AxleWeight6 = weighting.Axle6_Weight,
                            AxleWeight7 = weighting.Axle7_Weight,
                            AxleWeight8 = weighting.Axle8_Weight,

                            Width = weighting.Veh_Width,
                            Height = weighting.Veh_Height,
                            Length = weighting.Veh_Length,

                            UploadTime = DateTime.Now
                        };

                        #region process value
                        if (serverWeighting.Gross.HasValue)
                        {
                            if (serverWeighting.Gross.Value > 0)
                            {
                                serverWeighting.Gross /= 1000;
                            }
                        }
                        if (serverWeighting.LimitWeight.HasValue)
                        {
                            if (serverWeighting.LimitWeight.Value > 0)
                            {
                                serverWeighting.LimitWeight /= 1000;
                            }
                        }

                        if (serverWeighting.OverloadWeight.HasValue)
                        {
                            if (serverWeighting.OverloadWeight.Value > 0)
                            {
                                serverWeighting.OverloadWeight /= 1000;
                            }
                        }
                        
                        if (serverWeighting.OverloadWeight.HasValue && serverWeighting.LimitWeight.HasValue && serverWeighting.OverloadWeight.Value > 0 && serverWeighting.LimitWeight > 0)
                        {
                            serverWeighting.OverloadRate = serverWeighting.OverloadWeight.Value / serverWeighting.LimitWeight.Value;
                        }
                        else if (serverWeighting.OverloadRate.HasValue)
                        {
                            if (serverWeighting.OverloadRate.Value > 0)
                            {
                                serverWeighting.OverloadRate = serverWeighting.OverloadRate.Value / (decimal)100.00;
                            }
                        }

                        if (serverWeighting.WeightTime.HasValue)
                        {
                            serverWeighting.WeightTime_Year = serverWeighting.WeightTime.Value.Year;
                            serverWeighting.WeightTime_Month = serverWeighting.WeightTime.Value.Month;
                            serverWeighting.WeightTime_Day = serverWeighting.WeightTime.Value.Day;
                            serverWeighting.WeightTime_Hour = serverWeighting.WeightTime.Value.Hour;
                            serverWeighting.WeightTime_Minute = serverWeighting.WeightTime.Value.Minute;
                        }
                        #endregion

                        #region 附件
                        foreach (var file in weighting.WeightingFiles)
                        {
                            file.DeviceID = serverWeighting.DeviceID;
                            serverWeighting.WeightingFiles.Add(file);
                        }
                        #endregion


                        try
                        {
                            if (MSHO.Collection.DataAccess.MSHOService.Instance.SaveWeighting(clientConfig, serverWeighting))
                            {
                                msg.Result = true;
                                msg.DataId = weightId;
                                msg.WeightingFiles = serverWeighting.WeightingFiles.ToList();
                            }
                        }
                        catch (Exception ex)
                        {
                            MSHO.Collection.DataAccess.MSHOService.Instance.SaveSystemLog("MSHO.Collection.Service", "Process_LowSpeedNew_Weighting", ex);
                            msg.Result = false;
                            msg.DataId = weightId;
                        }
                    }
                }
            }
        }
    }
}
